:mod:`oujago.nlp.nertag`
============================

.. automodule:: oujago.nlp.nertag

.. autosummary::

    BaseNER
    LTPNER
    ner


Detailed Description
--------------------


.. autoclass:: BaseNER
    :members:


.. autoclass:: LTPNER
    :members:

.. autofunction:: ner
